@@ -66,17 +66,17 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
-		if jsonInput['outcome']['entities']['location']['value'] :
-			location = jsonInput['outcome']['entities']['location']['value']
-		else:
-			location = "pas de lieu"
-			bodies = ""
-
-		if jsonInput['outcome']['entities']['local_search_query']['value'] :
-			local = jsonInput['outcome']['entities']['local_search_query']['value']
-		else:
-			local = "pas de local_search_query"
-			bodies = ""
+#		if jsonInput['outcome']['entities']['location']['value'] :
+#			location = jsonInput['outcome']['entities']['location']['value']
+#		else:
+#			location = "pas de lieu"
+##			bodies = ""
+#
+#		if jsonInput['outcome']['entities']['local_search_query']['value'] :
+#			local = jsonInput['outcome']['entities']['local_search_query']['value']
+#		else:
+#			local = "pas de local_search_query"
+#			bodies = ""
 #
 		idex= local + " " + location +  "_"
 		log.msg("index :  %s" % (idex))		
